
Community
=========

This page brings together the various services we use to manage the community
and development.

Source Code
~~~~~~~~~~~

Source code is kindly hosted on Bitbucket_ using Mercurial_ source control. 

Grab the source:

.. code-block:: bash

	hg clone http://bitbucket.org/aafshar/pygtkhelpers-main

* `Browse the source online <http://bitbucket.org/aafshar/pygtkhelpers-main>`_
* `Browse a list of changesets <http://bitbucket.org/aafshar/pygtkhelpers-main/changes>`_

Bug reports
~~~~~~~~~~~

Bug reports and issue tracking are kindly hosted on Bitbucket_:

* `Create a new issue <http://bitbucket.org/aafshar/pygtkhelpers-main/issues/new>`_
* `List of issues <http://bitbucket.org/aafshar/pygtkhelpers-main/issues?status=new&status=open>`_

Mailing List
~~~~~~~~~~~~

The mailing list service is kindly hosted by Librelist_.

* Join the mailing list by simply mailing
  pygtkhelpers@librelist.com. (Your first mail will be ignored and used
  just for joining.)

IRC Channel
~~~~~~~~~~~

Our IRC channel is kindly hosted by Freenode_.

* ``irc.freenode.net`` in channel ``#pida``.

.. note::

	Our principal developers are based in Europe, so normal timezoning
	rules apply.

This website
~~~~~~~~~~~~

This website is kindly hosted by Python_.

.. _Bitbucket: http://bitbucket.org/
.. _Mercurial: http://mercurial.selenic.com/
.. _Freenode: http://freenode.net/
.. _Librelist: http://librelist.com/
.. _Python: http://python.org/

